# rapidata.api-client
The API for the Rapidata Asset service

The `rapidata.api_client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.0
- Generator version: 7.9.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3, < 3.0.0
* python-dateutil >= 2.8.2
* pydantic >= 2
* typing-extensions >= 4.7.1

## Getting Started

In your own code, to use this library to connect and interact with rapidata.api-client,
you can run the following:

```python

import rapidata.api_client
from rapidata.api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.rabbitdata.ch
# See configuration.py for a list of all supported configuration parameters.
configuration = rapidata.api_client.Configuration(
    host = "https://api.rabbitdata.ch"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]

# Configure Bearer authorization (Json Web Token): Bearer
configuration = rapidata.api_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with rapidata.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = rapidata.api_client.AssetApi(api_client)
    file_name = 'file_name_example' # str | The name of the file to retrieve metadata for.

    try:
        # Gets the metadata for an asset by file name.
        api_response = api_instance.asset_file_name_metadata_get(file_name)
        print("The response of AssetApi->asset_file_name_metadata_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AssetApi->asset_file_name_metadata_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.rabbitdata.ch*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AssetApi* | [**asset_file_name_metadata_get**](rapidata/api_client/docs/AssetApi.md#asset_file_name_metadata_get) | **GET** /asset/{fileName}/metadata | Gets the metadata for an asset by file name.
*AssetApi* | [**asset_file_post**](rapidata/api_client/docs/AssetApi.md#asset_file_post) | **POST** /asset/file | Uploads a single asset to S3 and returns the asset details.
*AssetApi* | [**asset_url_post**](rapidata/api_client/docs/AssetApi.md#asset_url_post) | **POST** /asset/url | Uploads a single asset to S3 and returns the asset details.
*AudienceApi* | [**audience_audience_id_get**](rapidata/api_client/docs/AudienceApi.md#audience_audience_id_get) | **GET** /audience/{audienceId} | Gets an audience by its Id.
*AudienceApi* | [**audience_audience_id_patch**](rapidata/api_client/docs/AudienceApi.md#audience_audience_id_patch) | **PATCH** /audience/{audienceId} | Patches an existing audience.
*AudienceApi* | [**audience_post**](rapidata/api_client/docs/AudienceApi.md#audience_post) | **POST** /audience | Creates a new empty audience.
*AudienceApi* | [**audiences_get**](rapidata/api_client/docs/AudienceApi.md#audiences_get) | **GET** /audiences | Queries all available audiences.
*BenchmarkApi* | [**benchmark_benchmark_id_delete**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_delete) | **DELETE** /benchmark/{benchmarkId} | Deletes a single benchmark.
*BenchmarkApi* | [**benchmark_benchmark_id_fork_post**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_fork_post) | **POST** /benchmark/{benchmarkId}/fork | Creates a copy of a public benchmark and all of its related entities
*BenchmarkApi* | [**benchmark_benchmark_id_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_get) | **GET** /benchmark/{benchmarkId} | Returns a single benchmark by its ID.
*BenchmarkApi* | [**benchmark_benchmark_id_leaderboards_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_leaderboards_get) | **GET** /benchmark/{benchmarkId}/leaderboards | Queries all leaderboards for the current user&#39;s benchmarks.
*BenchmarkApi* | [**benchmark_benchmark_id_participants_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_participants_get) | **GET** /benchmark/{benchmarkId}/participants | Query all participants within a benchmark
*BenchmarkApi* | [**benchmark_benchmark_id_participants_post**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_participants_post) | **POST** /benchmark/{benchmarkId}/participants | Creates a participant in a benchmark.
*BenchmarkApi* | [**benchmark_benchmark_id_patch**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_patch) | **PATCH** /benchmark/{benchmarkId} | Updates a benchmark using patch semantics.
*BenchmarkApi* | [**benchmark_benchmark_id_prompt_post**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_prompt_post) | **POST** /benchmark/{benchmarkId}/prompt | Adds a new prompt to a benchmark.
*BenchmarkApi* | [**benchmark_benchmark_id_prompts_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_prompts_get) | **GET** /benchmark/{benchmarkId}/prompts | Returns the paged prompts of a benchmark by its ID.
*BenchmarkApi* | [**benchmark_benchmark_id_samples_identifier_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_samples_identifier_get) | **GET** /benchmark/{benchmarkId}/samples/{identifier} | Returns the paged prompts of a benchmark by its ID.
*BenchmarkApi* | [**benchmark_benchmark_id_standings_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_standings_get) | **GET** /benchmark/{benchmarkId}/standings | 
*BenchmarkApi* | [**benchmark_benchmark_id_tags_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_tags_get) | **GET** /benchmark/{benchmarkId}/tags | Query all tags within a benchmark
*BenchmarkApi* | [**benchmark_post**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_post) | **POST** /benchmark | Creates a benchmark
*BenchmarkApi* | [**benchmarks_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmarks_get) | **GET** /benchmarks | Queries all benchmarks of the user.
*CampaignApi* | [**campaign_boost_put**](rapidata/api_client/docs/CampaignApi.md#campaign_boost_put) | **PUT** /campaign/boost | Updates the boost with manual boosts.
*CampaignApi* | [**campaign_boost_status_get**](rapidata/api_client/docs/CampaignApi.md#campaign_boost_status_get) | **GET** /campaign/boost/status | Gets the status of the boost.
*CampaignApi* | [**campaign_campaign_id_patch**](rapidata/api_client/docs/CampaignApi.md#campaign_campaign_id_patch) | **PATCH** /campaign/{campaignId} | Updates a campaign.
*CampaignApi* | [**campaign_campaign_id_pause_post**](rapidata/api_client/docs/CampaignApi.md#campaign_campaign_id_pause_post) | **POST** /campaign/{campaignId}/pause | Pauses a campaign.
*CampaignApi* | [**campaign_campaign_id_resume_post**](rapidata/api_client/docs/CampaignApi.md#campaign_campaign_id_resume_post) | **POST** /campaign/{campaignId}/resume | Resumes a campaign.
*CampaignApi* | [**campaign_monitor_get**](rapidata/api_client/docs/CampaignApi.md#campaign_monitor_get) | **GET** /campaign/monitor | The monitor endpoint is used to monitor the health of the service
*CampaignApi* | [**campaigns_get**](rapidata/api_client/docs/CampaignApi.md#campaigns_get) | **GET** /campaigns | Queries orders based on a filter, page, and sort criteria.
*ClientApi* | [**client_client_id_delete**](rapidata/api_client/docs/ClientApi.md#client_client_id_delete) | **DELETE** /client/{clientId} | Deletes a customers&#39; client.
*ClientApi* | [**client_client_id_get**](rapidata/api_client/docs/ClientApi.md#client_client_id_get) | **GET** /client/{clientId} | Gets a specific client by its ID.
*ClientApi* | [**client_post**](rapidata/api_client/docs/ClientApi.md#client_post) | **POST** /client | Creates a new client for the current customer.
*ClientApi* | [**client_register_post**](rapidata/api_client/docs/ClientApi.md#client_register_post) | **POST** /client/register | Registers a new client dynamically.
*ClientApi* | [**clients_get**](rapidata/api_client/docs/ClientApi.md#clients_get) | **GET** /clients | Queries the clients for the current customer.
*CompareWorkflowApi* | [**workflow_compare_workflow_id_results_get**](rapidata/api_client/docs/CompareWorkflowApi.md#workflow_compare_workflow_id_results_get) | **GET** /workflow/compare/{workflowId}/results | Get the result overview for a compare workflow.
*CustomerRapidApi* | [**rapid_correlation_id_validation_potential_get**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_correlation_id_validation_potential_get) | **GET** /rapid/{correlationId}/validation-potential | Queries rapids that are potentially eligible for validation set creation.
*CustomerRapidApi* | [**rapid_demographic_post**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_demographic_post) | **POST** /rapid/demographic | Creates a new Demographic Rapid with JSON body.
*CustomerRapidApi* | [**rapid_global_responses_get**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_global_responses_get) | **GET** /rapid/global-responses | A public endpoint to query the most recent responses globally
*CustomerRapidApi* | [**rapid_rapid_id_delete**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_rapid_id_delete) | **DELETE** /rapid/{rapidId} | Deletes a rapid.
*CustomerRapidApi* | [**rapid_rapid_id_responses_get**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_rapid_id_responses_get) | **GET** /rapid/{rapidId}/responses | Gets all responses for a given rapid.
*CustomerRapidApi* | [**rapid_rapid_id_unflag_post**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_rapid_id_unflag_post) | **POST** /rapid/{rapidId}/unflag | Unflags a flagged rapid.  This will add the rapid back to the active labeling pool and prevent it from being flagged again.
*CustomerRapidApi* | [**rapid_validation_rapid_id_patch**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_validation_rapid_id_patch) | **PATCH** /rapid/validation/{rapidId} | Updates the validation information of a Rapid.
*CustomerRapidApi* | [**rapids_flagged_get**](rapidata/api_client/docs/CustomerRapidApi.md#rapids_flagged_get) | **GET** /rapids/flagged | Allows querying all rapids that have been flagged.
*DatapointApi* | [**datapoint_datapoint_id_delete**](rapidata/api_client/docs/DatapointApi.md#datapoint_datapoint_id_delete) | **DELETE** /datapoint/{datapointId} | Deletes a datapoint by its id.
*DatapointApi* | [**datapoint_datapoint_id_get**](rapidata/api_client/docs/DatapointApi.md#datapoint_datapoint_id_get) | **GET** /datapoint/{datapointId} | Gets a datapoint by its id.
*DatasetApi* | [**dataset_dataset_id_datapoint_post**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoint_post) | **POST** /dataset/{datasetId}/datapoint | Creates a datapoint with JSON body.
*DatasetApi* | [**dataset_dataset_id_datapoints_failed_get**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_failed_get) | **GET** /dataset/{datasetId}/datapoints/failed | Gets a list of all datapoints that failed to upload.
*DatasetApi* | [**dataset_dataset_id_datapoints_get**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_get) | **GET** /dataset/{datasetId}/datapoints | Gets all datapoints of a dataset.
*DatasetApi* | [**dataset_dataset_id_get**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_get) | **GET** /dataset/{datasetId} | Gets a dataset by its id.
*DatasetApi* | [**dataset_dataset_id_name_patch**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_name_patch) | **PATCH** /dataset/{datasetId}/name | Updates the name of a dataset.
*DatasetApi* | [**dataset_dataset_id_progress_get**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_progress_get) | **GET** /dataset/{datasetId}/progress | Gets the upload progress of a dataset.
*EvaluationWorkflowApi* | [**workflow_evaluation_workflow_id_results_get**](rapidata/api_client/docs/EvaluationWorkflowApi.md#workflow_evaluation_workflow_id_results_get) | **GET** /workflow/evaluation/{workflowId}/results | Get the results for an evaluation workflow.
*FeedbackApi* | [**feedback_post**](rapidata/api_client/docs/FeedbackApi.md#feedback_post) | **POST** /feedback | Submits feedback about our services.
*GroupedRankingWorkflowApi* | [**workflow_grouped_ranking_workflow_id_results_get**](rapidata/api_client/docs/GroupedRankingWorkflowApi.md#workflow_grouped_ranking_workflow_id_results_get) | **GET** /workflow/grouped-ranking/{workflowId}/results | Get the result overview for a multi compare workflow.
*IdentityApi* | [**identity_bridge_token_get**](rapidata/api_client/docs/IdentityApi.md#identity_bridge_token_get) | **GET** /identity/bridge-token | Tries to read the bridge token keys for a given read key.  The read key is used to retrieve the authentication result written by the write key.
*IdentityApi* | [**identity_bridge_token_post**](rapidata/api_client/docs/IdentityApi.md#identity_bridge_token_post) | **POST** /identity/bridge-token | Creates a pair of read and write keys for a client.  The write key is used to store the authentication result.  The read key is used to retrieve the authentication result.
*IdentityApi* | [**identity_google_one_tap_post**](rapidata/api_client/docs/IdentityApi.md#identity_google_one_tap_post) | **POST** /identity/google-one-tap | Signs in a user using a token received from Google One Tap.
*IdentityApi* | [**identity_referrer_post**](rapidata/api_client/docs/IdentityApi.md#identity_referrer_post) | **POST** /identity/referrer | Sets the referrer for the current customer.
*LeaderboardApi* | [**benchmark_standing_leaderboard_id_participant_id_get**](rapidata/api_client/docs/LeaderboardApi.md#benchmark_standing_leaderboard_id_participant_id_get) | **GET** /benchmark/standing/{leaderboardId}/{participantId} | Gets a standing by leaderboardId and participantId.
*LeaderboardApi* | [**leaderboard_leaderboard_id_boost_post**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_boost_post) | **POST** /leaderboard/{leaderboardId}/boost | Boosts a subset of participants within a leaderboard.
*LeaderboardApi* | [**leaderboard_leaderboard_id_delete**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_delete) | **DELETE** /leaderboard/{leaderboardId} | Deletes a leaderboard by its ID.
*LeaderboardApi* | [**leaderboard_leaderboard_id_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_get) | **GET** /leaderboard/{leaderboardId} | Gets a leaderboard by its ID.
*LeaderboardApi* | [**leaderboard_leaderboard_id_patch**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_patch) | **PATCH** /leaderboard/{leaderboardId} | Updates the response config of a leaderboard.
*LeaderboardApi* | [**leaderboard_leaderboard_id_runs_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_runs_get) | **GET** /leaderboard/{leaderboardId}/runs | Gets the runs related to a leaderboard
*LeaderboardApi* | [**leaderboard_leaderboard_id_standings_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_standings_get) | **GET** /leaderboard/{leaderboardId}/standings | 
*LeaderboardApi* | [**leaderboard_post**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_post) | **POST** /leaderboard | Creates a new leaderboard with the specified name and criteria.
*LeaderboardApi* | [**leaderboards_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboards_get) | **GET** /leaderboards | Queries all leaderboards for a specific benchmark.
*NewsletterApi* | [**newsletter_subscribe_post**](rapidata/api_client/docs/NewsletterApi.md#newsletter_subscribe_post) | **POST** /newsletter/subscribe | Signs a user up to the newsletter.
*NewsletterApi* | [**newsletter_unsubscribe_post**](rapidata/api_client/docs/NewsletterApi.md#newsletter_unsubscribe_post) | **POST** /newsletter/unsubscribe | Unsubscribes a user from the newsletter.
*OrderApi* | [**order_complex_post**](rapidata/api_client/docs/OrderApi.md#order_complex_post) | **POST** /order/complex | Creates a new order with a custom pipeline.
*OrderApi* | [**order_order_id_approve_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_approve_post) | **POST** /order/{orderId}/approve | Approves an order that has been submitted for manual approval.
*OrderApi* | [**order_order_id_clone_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_clone_post) | **POST** /order/{orderId}/clone | Clones an existing order.
*OrderApi* | [**order_order_id_delete**](rapidata/api_client/docs/OrderApi.md#order_order_id_delete) | **DELETE** /order/{orderId} | Deletes an order.
*OrderApi* | [**order_order_id_demo_patch**](rapidata/api_client/docs/OrderApi.md#order_order_id_demo_patch) | **PATCH** /order/{orderId}/demo | Updates whether an order is a demo or not.
*OrderApi* | [**order_order_id_download_results_get**](rapidata/api_client/docs/OrderApi.md#order_order_id_download_results_get) | **GET** /order/{orderId}/download-results | Aggregates the results of an order and returns it as a file attachment.
*OrderApi* | [**order_order_id_get**](rapidata/api_client/docs/OrderApi.md#order_order_id_get) | **GET** /order/{orderId} | Retrieves an order by its id.
*OrderApi* | [**order_order_id_name_patch**](rapidata/api_client/docs/OrderApi.md#order_order_id_name_patch) | **PATCH** /order/{orderId}/name | Updates the name of an order.
*OrderApi* | [**order_order_id_pause_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_pause_post) | **POST** /order/{orderId}/pause | Pauses an order that is processing. Meaning all campaigns in the order will be paused.
*OrderApi* | [**order_order_id_preview_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_preview_post) | **POST** /order/{orderId}/preview | Puts the order into preview mode, where one can inspect what our labelers receive.
*OrderApi* | [**order_order_id_results_get**](rapidata/api_client/docs/OrderApi.md#order_order_id_results_get) | **GET** /order/{orderId}/results | Aggregates the results of an order and returns the result as a json body.
*OrderApi* | [**order_order_id_resume_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_resume_post) | **POST** /order/{orderId}/resume | Resumes a paused order. Meaning all campaigns in the order will be resumed.
*OrderApi* | [**order_order_id_retry_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_retry_post) | **POST** /order/{orderId}/retry | Retries a failed order.
*OrderApi* | [**order_order_id_share_patch**](rapidata/api_client/docs/OrderApi.md#order_order_id_share_patch) | **PATCH** /order/{orderId}/share | Updates whether an order is public or not.
*OrderApi* | [**order_order_id_submit_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_submit_post) | **POST** /order/{orderId}/submit | Submits an order for approval.
*OrderApi* | [**order_order_id_unlock_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_unlock_post) | **POST** /order/{orderId}/unlock | Unlocks a newly cloned order.
*OrderApi* | [**order_post**](rapidata/api_client/docs/OrderApi.md#order_post) | **POST** /order | Used to create a new order.
*OrderApi* | [**order_unsupported_post**](rapidata/api_client/docs/OrderApi.md#order_unsupported_post) | **POST** /order/unsupported | Notifies the admins that a user wants to create an order with an unsupported label type or data type.
*OrderApi* | [**orders_aggregated_overview_get**](rapidata/api_client/docs/OrderApi.md#orders_aggregated_overview_get) | **GET** /orders/aggregated-overview | Retrieves the orders aggregated by customer, with total amounts and most recent order informations.
*OrderApi* | [**orders_get**](rapidata/api_client/docs/OrderApi.md#orders_get) | **GET** /orders | Queries orders based on a filter, page, and sort criteria.
*OrderApi* | [**orders_public_get**](rapidata/api_client/docs/OrderApi.md#orders_public_get) | **GET** /orders/public | Retrieves orders that are public and can be cloned by any user.
*ParticipantApi* | [**participant_participant_id_delete**](rapidata/api_client/docs/ParticipantApi.md#participant_participant_id_delete) | **DELETE** /participant/{participantId} | Deletes a participant on a benchmark.
*ParticipantApi* | [**participant_participant_id_disable_post**](rapidata/api_client/docs/ParticipantApi.md#participant_participant_id_disable_post) | **POST** /participant/{participantId}/disable | This endpoint disables a participant in a benchmark. this means that the participant will no longer actively be matched up against other participants and not collect further results. It will still be visible in the leaderboard.
*ParticipantApi* | [**participant_participant_id_get**](rapidata/api_client/docs/ParticipantApi.md#participant_participant_id_get) | **GET** /participant/{participantId} | Gets a participant by it&#39;s Id.
*ParticipantApi* | [**participant_participant_id_patch**](rapidata/api_client/docs/ParticipantApi.md#participant_participant_id_patch) | **PATCH** /participant/{participantId} | Updates a participant using patch semantics.
*ParticipantApi* | [**participant_participant_id_sample_post**](rapidata/api_client/docs/ParticipantApi.md#participant_participant_id_sample_post) | **POST** /participant/{participantId}/sample | Adds a sample to a participant.
*ParticipantApi* | [**participant_participant_id_samples_get**](rapidata/api_client/docs/ParticipantApi.md#participant_participant_id_samples_get) | **GET** /participant/{participantId}/samples | Queries all samples of a participant.
*ParticipantApi* | [**participant_sample_sample_id_delete**](rapidata/api_client/docs/ParticipantApi.md#participant_sample_sample_id_delete) | **DELETE** /participant-sample/{sampleId} | Deletes a sample.
*ParticipantApi* | [**participants_participant_id_submit_post**](rapidata/api_client/docs/ParticipantApi.md#participants_participant_id_submit_post) | **POST** /participants/{participantId}/submit | Submits a participant to a benchmark.
*PipelineApi* | [**pipeline_pipeline_id_get**](rapidata/api_client/docs/PipelineApi.md#pipeline_pipeline_id_get) | **GET** /pipeline/{pipelineId} | Gets a pipeline by its id.
*PipelineApi* | [**pipeline_pipeline_id_preliminary_download_post**](rapidata/api_client/docs/PipelineApi.md#pipeline_pipeline_id_preliminary_download_post) | **POST** /pipeline/{pipelineId}/preliminary-download | Initiates a preliminary download of the pipeline.
*PipelineApi* | [**pipeline_preliminary_download_preliminary_download_id_get**](rapidata/api_client/docs/PipelineApi.md#pipeline_preliminary_download_preliminary_download_id_get) | **GET** /pipeline/preliminary-download/{preliminaryDownloadId} | Gets the preliminary download.
*PromptApi* | [**benchmark_prompt_prompt_id_tags_put**](rapidata/api_client/docs/PromptApi.md#benchmark_prompt_prompt_id_tags_put) | **PUT** /benchmark-prompt/{promptId}/tags | Updates the tags associated with a prompt.
*RapidataIdentityAPIApi* | [**root_get**](rapidata/api_client/docs/RapidataIdentityAPIApi.md#root_get) | **GET** / | 
*SampleApi* | [**benchmark_sample_sample_id_get**](rapidata/api_client/docs/SampleApi.md#benchmark_sample_sample_id_get) | **GET** /benchmark-sample/{sampleId} | Gets a sample by its Id.
*SimpleWorkflowApi* | [**workflow_simple_workflow_id_results_get**](rapidata/api_client/docs/SimpleWorkflowApi.md#workflow_simple_workflow_id_results_get) | **GET** /workflow/simple/{workflowId}/results | Get the result overview for a simple workflow.
*SurveyApi* | [**identity_survey_post**](rapidata/api_client/docs/SurveyApi.md#identity_survey_post) | **POST** /identity/survey | Sends a survey.
*UserRapidApi* | [**rapid_rapid_bag_is_valid_get**](rapidata/api_client/docs/UserRapidApi.md#rapid_rapid_bag_is_valid_get) | **GET** /rapid/rapid-bag/is-valid | Validates that the rapids associated with the current user are active.
*UserRapidApi* | [**rapid_rapid_id_report_post**](rapidata/api_client/docs/UserRapidApi.md#rapid_rapid_id_report_post) | **POST** /rapid/{rapidId}/report | Used to report an issue with a rapid.
*UserRapidApi* | [**rapid_report_report_id_get**](rapidata/api_client/docs/UserRapidApi.md#rapid_report_report_id_get) | **GET** /rapid/report/{reportId} | Inspects a report&#39;s dump. Can be used to restore zustand state or anything alike.
*UserRapidApi* | [**rapid_response_post**](rapidata/api_client/docs/UserRapidApi.md#rapid_response_post) | **POST** /rapid/response | Submits a response for a Rapid.
*UserRapidApi* | [**rapid_skip_post**](rapidata/api_client/docs/UserRapidApi.md#rapid_skip_post) | **POST** /rapid/skip | Skips a Rapid for the user.
*ValidationSetApi* | [**validation_set_post**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_post) | **POST** /validation-set | Creates a new empty validation set.
*ValidationSetApi* | [**validation_set_recommended_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_recommended_get) | **GET** /validation-set/recommended | 
*ValidationSetApi* | [**validation_set_validation_set_id_delete**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_delete) | **DELETE** /validation-set/{validationSetId} | Gets a validation set by the id.
*ValidationSetApi* | [**validation_set_validation_set_id_export_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_export_get) | **GET** /validation-set/{validationSetId}/export | Exports all rapids of a validation-set to a file.
*ValidationSetApi* | [**validation_set_validation_set_id_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_get) | **GET** /validation-set/{validationSetId} | Gets a validation set by the id.
*ValidationSetApi* | [**validation_set_validation_set_id_patch**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_patch) | **PATCH** /validation-set/{validationSetId} | Updates different characteristics of a validation set.
*ValidationSetApi* | [**validation_set_validation_set_id_rapid_post**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_rapid_post) | **POST** /validation-set/{validationSetId}/rapid | Adds a new validation rapid to the validation set using JSON body.
*ValidationSetApi* | [**validation_set_validation_set_id_rapids_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_rapids_get) | **GET** /validation-set/{validationSetId}/rapids | Queries the validation rapids for a specific validation set.
*ValidationSetApi* | [**validation_set_validation_set_id_visibility_patch**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_visibility_patch) | **PATCH** /validation-set/{validationSetId}/visibility | Updates the visibility of a validation set.
*ValidationSetApi* | [**validation_sets_available_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_sets_available_get) | **GET** /validation-sets/available | Gets the available validation sets for the current user.
*ValidationSetApi* | [**validation_sets_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_sets_get) | **GET** /validation-sets | Queries available validation sets based on the provided filter, paging and sorting criteria.
*WorkflowApi* | [**workflow_delete_delete**](rapidata/api_client/docs/WorkflowApi.md#workflow_delete_delete) | **DELETE** /workflow/delete | Deletes a workflow.
*WorkflowApi* | [**workflow_workflow_id_compare_ab_summary_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_workflow_id_compare_ab_summary_get) | **GET** /workflow/{workflowId}/compare-ab-summary | Calculates a summary of the results for a simple compare workflow.  The summary includes the number of times an asset at each index was the winner.
*WorkflowApi* | [**workflow_workflow_id_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_workflow_id_get) | **GET** /workflow/{workflowId} | Get a workflow by its ID.
*WorkflowApi* | [**workflow_workflow_id_progress_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_workflow_id_progress_get) | **GET** /workflow/{workflowId}/progress | Get the progress of a workflow.
*WorkflowApi* | [**workflow_workflow_id_responses_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_workflow_id_responses_get) | **GET** /workflow/{workflowId}/responses | Gets the limit most recent or oldest responses for a workflow.  The responses are not guaranteed to be of any specific rapid.  Instead, this endpoint returns all responses to any rapid in the workflow.
*WorkflowApi* | [**workflows_get**](rapidata/api_client/docs/WorkflowApi.md#workflows_get) | **GET** /workflows | Queries workflows based on the provided filter, page, and sort criteria.


## Documentation For Models

 - [AddUserResponseResult](rapidata/api_client/docs/AddUserResponseResult.md)
 - [AddValidationRapidModel](rapidata/api_client/docs/AddValidationRapidModel.md)
 - [AddValidationRapidNewModel](rapidata/api_client/docs/AddValidationRapidNewModel.md)
 - [AggregatedOrdersModel](rapidata/api_client/docs/AggregatedOrdersModel.md)
 - [AggregatorType](rapidata/api_client/docs/AggregatorType.md)
 - [AreRapidsActiveResult](rapidata/api_client/docs/AreRapidsActiveResult.md)
 - [AttachCategoryRapidBlueprintCategory](rapidata/api_client/docs/AttachCategoryRapidBlueprintCategory.md)
 - [AudienceStatus](rapidata/api_client/docs/AudienceStatus.md)
 - [BenchmarkQueryResult](rapidata/api_client/docs/BenchmarkQueryResult.md)
 - [BoostLeaderboardModel](rapidata/api_client/docs/BoostLeaderboardModel.md)
 - [BoostingProfile](rapidata/api_client/docs/BoostingProfile.md)
 - [BoxShape](rapidata/api_client/docs/BoxShape.md)
 - [CampaignQueryResult](rapidata/api_client/docs/CampaignQueryResult.md)
 - [CampaignStatus](rapidata/api_client/docs/CampaignStatus.md)
 - [ChangeBoostModel](rapidata/api_client/docs/ChangeBoostModel.md)
 - [ClassifyPayload](rapidata/api_client/docs/ClassifyPayload.md)
 - [ClassifyPayloadCategory](rapidata/api_client/docs/ClassifyPayloadCategory.md)
 - [ClientModel](rapidata/api_client/docs/ClientModel.md)
 - [ClientsQueryResult](rapidata/api_client/docs/ClientsQueryResult.md)
 - [CloneOrderModel](rapidata/api_client/docs/CloneOrderModel.md)
 - [CloneOrderResult](rapidata/api_client/docs/CloneOrderResult.md)
 - [ComparisonOperator](rapidata/api_client/docs/ComparisonOperator.md)
 - [ConditionalValidationSelectionValidationChance](rapidata/api_client/docs/ConditionalValidationSelectionValidationChance.md)
 - [ConfidenceInterval](rapidata/api_client/docs/ConfidenceInterval.md)
 - [CreateAudienceRequest](rapidata/api_client/docs/CreateAudienceRequest.md)
 - [CreateAudienceResult](rapidata/api_client/docs/CreateAudienceResult.md)
 - [CreateBenchmarkModel](rapidata/api_client/docs/CreateBenchmarkModel.md)
 - [CreateBenchmarkParticipantModel](rapidata/api_client/docs/CreateBenchmarkParticipantModel.md)
 - [CreateBenchmarkParticipantResult](rapidata/api_client/docs/CreateBenchmarkParticipantResult.md)
 - [CreateBenchmarkPromptResult](rapidata/api_client/docs/CreateBenchmarkPromptResult.md)
 - [CreateBenchmarkResult](rapidata/api_client/docs/CreateBenchmarkResult.md)
 - [CreateBridgeTokenResult](rapidata/api_client/docs/CreateBridgeTokenResult.md)
 - [CreateClientModel](rapidata/api_client/docs/CreateClientModel.md)
 - [CreateComplexOrderModel](rapidata/api_client/docs/CreateComplexOrderModel.md)
 - [CreateComplexOrderResult](rapidata/api_client/docs/CreateComplexOrderResult.md)
 - [CreateCustomerClientResult](rapidata/api_client/docs/CreateCustomerClientResult.md)
 - [CreateDatapointModel](rapidata/api_client/docs/CreateDatapointModel.md)
 - [CreateDatapointResult](rapidata/api_client/docs/CreateDatapointResult.md)
 - [CreateDemographicRapidModel](rapidata/api_client/docs/CreateDemographicRapidModel.md)
 - [CreateEmptyValidationSetResult](rapidata/api_client/docs/CreateEmptyValidationSetResult.md)
 - [CreateLeaderboardModel](rapidata/api_client/docs/CreateLeaderboardModel.md)
 - [CreateLeaderboardResult](rapidata/api_client/docs/CreateLeaderboardResult.md)
 - [CreateOrderModel](rapidata/api_client/docs/CreateOrderModel.md)
 - [CreateOrderResult](rapidata/api_client/docs/CreateOrderResult.md)
 - [CreateRapidResult](rapidata/api_client/docs/CreateRapidResult.md)
 - [CreateSampleModel](rapidata/api_client/docs/CreateSampleModel.md)
 - [CreateUnsupportedOrderModel](rapidata/api_client/docs/CreateUnsupportedOrderModel.md)
 - [CreateValidationSetModel](rapidata/api_client/docs/CreateValidationSetModel.md)
 - [DatapointState](rapidata/api_client/docs/DatapointState.md)
 - [DynamicClientRegistrationRequest](rapidata/api_client/docs/DynamicClientRegistrationRequest.md)
 - [EloConfig](rapidata/api_client/docs/EloConfig.md)
 - [EloConfigModel](rapidata/api_client/docs/EloConfigModel.md)
 - [FeatureFlag](rapidata/api_client/docs/FeatureFlag.md)
 - [FeatureFlagModel](rapidata/api_client/docs/FeatureFlagModel.md)
 - [FeedbackModel](rapidata/api_client/docs/FeedbackModel.md)
 - [FileType](rapidata/api_client/docs/FileType.md)
 - [Filter](rapidata/api_client/docs/Filter.md)
 - [FilterOperator](rapidata/api_client/docs/FilterOperator.md)
 - [ForkBenchmarkResult](rapidata/api_client/docs/ForkBenchmarkResult.md)
 - [GetAudienceByIdResult](rapidata/api_client/docs/GetAudienceByIdResult.md)
 - [GetAvailableValidationSetsResult](rapidata/api_client/docs/GetAvailableValidationSetsResult.md)
 - [GetBenchmarkByIdResult](rapidata/api_client/docs/GetBenchmarkByIdResult.md)
 - [GetBoostResult](rapidata/api_client/docs/GetBoostResult.md)
 - [GetBoostResultBoostMode](rapidata/api_client/docs/GetBoostResultBoostMode.md)
 - [GetBoostResultBoostStatus](rapidata/api_client/docs/GetBoostResultBoostStatus.md)
 - [GetCompareAbSummaryResult](rapidata/api_client/docs/GetCompareAbSummaryResult.md)
 - [GetCompareWorkflowResultsModel](rapidata/api_client/docs/GetCompareWorkflowResultsModel.md)
 - [GetCompareWorkflowResultsResult](rapidata/api_client/docs/GetCompareWorkflowResultsResult.md)
 - [GetDatapointByIdResult](rapidata/api_client/docs/GetDatapointByIdResult.md)
 - [GetDatasetByIdResult](rapidata/api_client/docs/GetDatasetByIdResult.md)
 - [GetDatasetProgressResult](rapidata/api_client/docs/GetDatasetProgressResult.md)
 - [GetEvaluationWorkflowResultsModel](rapidata/api_client/docs/GetEvaluationWorkflowResultsModel.md)
 - [GetFailedDatapointsResult](rapidata/api_client/docs/GetFailedDatapointsResult.md)
 - [GetFailedDatapointsResultDatapoint](rapidata/api_client/docs/GetFailedDatapointsResultDatapoint.md)
 - [GetFileMetadataResult](rapidata/api_client/docs/GetFileMetadataResult.md)
 - [GetGroupedRankingWorkflowResultsModel](rapidata/api_client/docs/GetGroupedRankingWorkflowResultsModel.md)
 - [GetGroupedRankingWorkflowResultsResult](rapidata/api_client/docs/GetGroupedRankingWorkflowResultsResult.md)
 - [GetLeaderboardByIdResult](rapidata/api_client/docs/GetLeaderboardByIdResult.md)
 - [GetOrderByIdResult](rapidata/api_client/docs/GetOrderByIdResult.md)
 - [GetParticipantByIdResult](rapidata/api_client/docs/GetParticipantByIdResult.md)
 - [GetPipelineByIdResult](rapidata/api_client/docs/GetPipelineByIdResult.md)
 - [GetPublicOrdersResult](rapidata/api_client/docs/GetPublicOrdersResult.md)
 - [GetPublicResponsesResult](rapidata/api_client/docs/GetPublicResponsesResult.md)
 - [GetPublicResponsesResultResponse](rapidata/api_client/docs/GetPublicResponsesResultResponse.md)
 - [GetRecommendedValidationSetResult](rapidata/api_client/docs/GetRecommendedValidationSetResult.md)
 - [GetResponsesForRapidResult](rapidata/api_client/docs/GetResponsesForRapidResult.md)
 - [GetResponsesForRapidResultResponse](rapidata/api_client/docs/GetResponsesForRapidResultResponse.md)
 - [GetResponsesResult](rapidata/api_client/docs/GetResponsesResult.md)
 - [GetResponsesResultResponse](rapidata/api_client/docs/GetResponsesResultResponse.md)
 - [GetSampleByIdResult](rapidata/api_client/docs/GetSampleByIdResult.md)
 - [GetSimpleWorkflowResultsModel](rapidata/api_client/docs/GetSimpleWorkflowResultsModel.md)
 - [GetStandingByIdResult](rapidata/api_client/docs/GetStandingByIdResult.md)
 - [GetValidationRapidsResult](rapidata/api_client/docs/GetValidationRapidsResult.md)
 - [GetValidationSetByIdResult](rapidata/api_client/docs/GetValidationSetByIdResult.md)
 - [GetWorkflowByIdResult](rapidata/api_client/docs/GetWorkflowByIdResult.md)
 - [GetWorkflowProgressResult](rapidata/api_client/docs/GetWorkflowProgressResult.md)
 - [GetWorkflowResultsResult](rapidata/api_client/docs/GetWorkflowResultsResult.md)
 - [GetWorkflowResultsResultResponse](rapidata/api_client/docs/GetWorkflowResultsResultResponse.md)
 - [GoogleOneTapLoginModel](rapidata/api_client/docs/GoogleOneTapLoginModel.md)
 - [IArtifactModel](rapidata/api_client/docs/IArtifactModel.md)
 - [IArtifactModelCampaignArtifactModel](rapidata/api_client/docs/IArtifactModelCampaignArtifactModel.md)
 - [IArtifactModelDatasetArtifactModel](rapidata/api_client/docs/IArtifactModelDatasetArtifactModel.md)
 - [IArtifactModelFileArtifactModel](rapidata/api_client/docs/IArtifactModelFileArtifactModel.md)
 - [IArtifactModelWorkflowArtifactModel](rapidata/api_client/docs/IArtifactModelWorkflowArtifactModel.md)
 - [IArtifactModelWorkflowConfigArtifactModel](rapidata/api_client/docs/IArtifactModelWorkflowConfigArtifactModel.md)
 - [IAsset](rapidata/api_client/docs/IAsset.md)
 - [IAssetFileAsset](rapidata/api_client/docs/IAssetFileAsset.md)
 - [IAssetInput](rapidata/api_client/docs/IAssetInput.md)
 - [IAssetInputExistingAssetInput](rapidata/api_client/docs/IAssetInputExistingAssetInput.md)
 - [IAssetInputMultiAssetInput](rapidata/api_client/docs/IAssetInputMultiAssetInput.md)
 - [IAssetInputTextAssetInput](rapidata/api_client/docs/IAssetInputTextAssetInput.md)
 - [IAssetModel](rapidata/api_client/docs/IAssetModel.md)
 - [IAssetModelFileAssetModel](rapidata/api_client/docs/IAssetModelFileAssetModel.md)
 - [IAssetModelMultiAssetModel](rapidata/api_client/docs/IAssetModelMultiAssetModel.md)
 - [IAssetModelNullAssetModel](rapidata/api_client/docs/IAssetModelNullAssetModel.md)
 - [IAssetModelTextAssetModel](rapidata/api_client/docs/IAssetModelTextAssetModel.md)
 - [IAssetMultiAsset](rapidata/api_client/docs/IAssetMultiAsset.md)
 - [IAssetNullAsset](rapidata/api_client/docs/IAssetNullAsset.md)
 - [IAssetTextAsset](rapidata/api_client/docs/IAssetTextAsset.md)
 - [ICampaignFilter](rapidata/api_client/docs/ICampaignFilter.md)
 - [ICampaignFilterAndFilter](rapidata/api_client/docs/ICampaignFilterAndFilter.md)
 - [ICampaignFilterCampaignFilter](rapidata/api_client/docs/ICampaignFilterCampaignFilter.md)
 - [ICampaignFilterCountryFilter](rapidata/api_client/docs/ICampaignFilterCountryFilter.md)
 - [ICampaignFilterDemographicFilter](rapidata/api_client/docs/ICampaignFilterDemographicFilter.md)
 - [ICampaignFilterLanguageFilter](rapidata/api_client/docs/ICampaignFilterLanguageFilter.md)
 - [ICampaignFilterNewUserFilter](rapidata/api_client/docs/ICampaignFilterNewUserFilter.md)
 - [ICampaignFilterNotFilter](rapidata/api_client/docs/ICampaignFilterNotFilter.md)
 - [ICampaignFilterOrFilter](rapidata/api_client/docs/ICampaignFilterOrFilter.md)
 - [ICampaignFilterResponseCountFilter](rapidata/api_client/docs/ICampaignFilterResponseCountFilter.md)
 - [ICampaignFilterUserActionRestrictionFilter](rapidata/api_client/docs/ICampaignFilterUserActionRestrictionFilter.md)
 - [ICampaignFilterUserScoreFilter](rapidata/api_client/docs/ICampaignFilterUserScoreFilter.md)
 - [ICampaignFilterUserStateFilter](rapidata/api_client/docs/ICampaignFilterUserStateFilter.md)
 - [IDatasetMetadataInput](rapidata/api_client/docs/IDatasetMetadataInput.md)
 - [IDatasetMetadataInputPromptAssetMetadataInput](rapidata/api_client/docs/IDatasetMetadataInputPromptAssetMetadataInput.md)
 - [IDatasetMetadataInputPromptMetadataInput](rapidata/api_client/docs/IDatasetMetadataInputPromptMetadataInput.md)
 - [IDatasetMetadataInputTranscriptionMetadataInput](rapidata/api_client/docs/IDatasetMetadataInputTranscriptionMetadataInput.md)
 - [IDatasetModel](rapidata/api_client/docs/IDatasetModel.md)
 - [IDatasetModelCloneDatasetModel](rapidata/api_client/docs/IDatasetModelCloneDatasetModel.md)
 - [IMetadata](rapidata/api_client/docs/IMetadata.md)
 - [IMetadataClassificationMetadata](rapidata/api_client/docs/IMetadataClassificationMetadata.md)
 - [IMetadataCountMetadata](rapidata/api_client/docs/IMetadataCountMetadata.md)
 - [IMetadataFileTypeMetadata](rapidata/api_client/docs/IMetadataFileTypeMetadata.md)
 - [IMetadataImageDimensionMetadata](rapidata/api_client/docs/IMetadataImageDimensionMetadata.md)
 - [IMetadataInput](rapidata/api_client/docs/IMetadataInput.md)
 - [IMetadataInputTextMetadataInput](rapidata/api_client/docs/IMetadataInputTextMetadataInput.md)
 - [IMetadataLocationMetadata](rapidata/api_client/docs/IMetadataLocationMetadata.md)
 - [IMetadataModel](rapidata/api_client/docs/IMetadataModel.md)
 - [IMetadataModelClassificationMetadataModel](rapidata/api_client/docs/IMetadataModelClassificationMetadataModel.md)
 - [IMetadataModelCountMetadataModel](rapidata/api_client/docs/IMetadataModelCountMetadataModel.md)
 - [IMetadataModelFileTypeMetadataModel](rapidata/api_client/docs/IMetadataModelFileTypeMetadataModel.md)
 - [IMetadataModelImageDimensionMetadataModel](rapidata/api_client/docs/IMetadataModelImageDimensionMetadataModel.md)
 - [IMetadataModelLocationMetadataModel](rapidata/api_client/docs/IMetadataModelLocationMetadataModel.md)
 - [IMetadataModelOriginalFilenameMetadataModel](rapidata/api_client/docs/IMetadataModelOriginalFilenameMetadataModel.md)
 - [IMetadataModelSourceUrlMetadataModel](rapidata/api_client/docs/IMetadataModelSourceUrlMetadataModel.md)
 - [IMetadataModelStreamsMetadataModel](rapidata/api_client/docs/IMetadataModelStreamsMetadataModel.md)
 - [IMetadataModelTextMetadataModel](rapidata/api_client/docs/IMetadataModelTextMetadataModel.md)
 - [IMetadataModelVideoDurationMetadataModel](rapidata/api_client/docs/IMetadataModelVideoDurationMetadataModel.md)
 - [IMetadataOriginalFilenameMetadata](rapidata/api_client/docs/IMetadataOriginalFilenameMetadata.md)
 - [IMetadataSourceUrlMetadata](rapidata/api_client/docs/IMetadataSourceUrlMetadata.md)
 - [IMetadataStreamsMetadata](rapidata/api_client/docs/IMetadataStreamsMetadata.md)
 - [IMetadataTextMetadata](rapidata/api_client/docs/IMetadataTextMetadata.md)
 - [IMetadataVideoDurationMetadata](rapidata/api_client/docs/IMetadataVideoDurationMetadata.md)
 - [IOrderWorkflowModel](rapidata/api_client/docs/IOrderWorkflowModel.md)
 - [IOrderWorkflowModelCompareWorkflowModel](rapidata/api_client/docs/IOrderWorkflowModelCompareWorkflowModel.md)
 - [IOrderWorkflowModelEvaluationWorkflowModel](rapidata/api_client/docs/IOrderWorkflowModelEvaluationWorkflowModel.md)
 - [IOrderWorkflowModelGroupedRankingWorkflowModel](rapidata/api_client/docs/IOrderWorkflowModelGroupedRankingWorkflowModel.md)
 - [IOrderWorkflowModelSimpleWorkflowModel](rapidata/api_client/docs/IOrderWorkflowModelSimpleWorkflowModel.md)
 - [IPairMakerConfig](rapidata/api_client/docs/IPairMakerConfig.md)
 - [IPairMakerConfigModel](rapidata/api_client/docs/IPairMakerConfigModel.md)
 - [IPairMakerConfigModelOnlinePairMakerConfigModel](rapidata/api_client/docs/IPairMakerConfigModelOnlinePairMakerConfigModel.md)
 - [IPairMakerConfigOnlinePairMakerConfig](rapidata/api_client/docs/IPairMakerConfigOnlinePairMakerConfig.md)
 - [IPairMakerInformation](rapidata/api_client/docs/IPairMakerInformation.md)
 - [IPairMakerInformationOnlinePairMakerInformation](rapidata/api_client/docs/IPairMakerInformationOnlinePairMakerInformation.md)
 - [IPipelineArtifactModel](rapidata/api_client/docs/IPipelineArtifactModel.md)
 - [IPipelineArtifactModelCreateDatasetArtifactModel](rapidata/api_client/docs/IPipelineArtifactModelCreateDatasetArtifactModel.md)
 - [IPipelineModel](rapidata/api_client/docs/IPipelineModel.md)
 - [IPipelineModelCreateSimplePipelineModel](rapidata/api_client/docs/IPipelineModelCreateSimplePipelineModel.md)
 - [IPipelineStepModel](rapidata/api_client/docs/IPipelineStepModel.md)
 - [IPipelineStepModelDatasetEvaluationStepModel](rapidata/api_client/docs/IPipelineStepModelDatasetEvaluationStepModel.md)
 - [IPipelineStepModelSendCompletionMailStepModel](rapidata/api_client/docs/IPipelineStepModelSendCompletionMailStepModel.md)
 - [IPipelineStepModelWorkflowAggregationStepModel](rapidata/api_client/docs/IPipelineStepModelWorkflowAggregationStepModel.md)
 - [IPipelineStepModelWorkflowLabelingStepModel](rapidata/api_client/docs/IPipelineStepModelWorkflowLabelingStepModel.md)
 - [IRapidBlueprint](rapidata/api_client/docs/IRapidBlueprint.md)
 - [IRapidBlueprintAttachCategoryRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintAttachCategoryRapidBlueprint.md)
 - [IRapidBlueprintBoundingBoxRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintBoundingBoxRapidBlueprint.md)
 - [IRapidBlueprintCompareRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintCompareRapidBlueprint.md)
 - [IRapidBlueprintFreeTextRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintFreeTextRapidBlueprint.md)
 - [IRapidBlueprintLineRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintLineRapidBlueprint.md)
 - [IRapidBlueprintLocateRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintLocateRapidBlueprint.md)
 - [IRapidBlueprintNamedEntityRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintNamedEntityRapidBlueprint.md)
 - [IRapidBlueprintPolygonRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintPolygonRapidBlueprint.md)
 - [IRapidBlueprintScrubRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintScrubRapidBlueprint.md)
 - [IRapidBlueprintTranscriptionRapidBlueprint](rapidata/api_client/docs/IRapidBlueprintTranscriptionRapidBlueprint.md)
 - [IRapidPayload](rapidata/api_client/docs/IRapidPayload.md)
 - [IRapidPayloadBoundingBoxPayload](rapidata/api_client/docs/IRapidPayloadBoundingBoxPayload.md)
 - [IRapidPayloadClassifyPayload](rapidata/api_client/docs/IRapidPayloadClassifyPayload.md)
 - [IRapidPayloadComparePayload](rapidata/api_client/docs/IRapidPayloadComparePayload.md)
 - [IRapidPayloadFreeTextPayload](rapidata/api_client/docs/IRapidPayloadFreeTextPayload.md)
 - [IRapidPayloadLinePayload](rapidata/api_client/docs/IRapidPayloadLinePayload.md)
 - [IRapidPayloadLocatePayload](rapidata/api_client/docs/IRapidPayloadLocatePayload.md)
 - [IRapidPayloadNamedEntityPayload](rapidata/api_client/docs/IRapidPayloadNamedEntityPayload.md)
 - [IRapidPayloadPolygonPayload](rapidata/api_client/docs/IRapidPayloadPolygonPayload.md)
 - [IRapidPayloadScrubPayload](rapidata/api_client/docs/IRapidPayloadScrubPayload.md)
 - [IRapidPayloadTranscriptionPayload](rapidata/api_client/docs/IRapidPayloadTranscriptionPayload.md)
 - [IRapidResult](rapidata/api_client/docs/IRapidResult.md)
 - [IRapidResultAttachCategoryResult](rapidata/api_client/docs/IRapidResultAttachCategoryResult.md)
 - [IRapidResultBoundingBoxResult](rapidata/api_client/docs/IRapidResultBoundingBoxResult.md)
 - [IRapidResultCompareResult](rapidata/api_client/docs/IRapidResultCompareResult.md)
 - [IRapidResultFreeTextResult](rapidata/api_client/docs/IRapidResultFreeTextResult.md)
 - [IRapidResultLineResult](rapidata/api_client/docs/IRapidResultLineResult.md)
 - [IRapidResultLocateResult](rapidata/api_client/docs/IRapidResultLocateResult.md)
 - [IRapidResultNamedEntityResult](rapidata/api_client/docs/IRapidResultNamedEntityResult.md)
 - [IRapidResultPolygonResult](rapidata/api_client/docs/IRapidResultPolygonResult.md)
 - [IRapidResultScrubResult](rapidata/api_client/docs/IRapidResultScrubResult.md)
 - [IRapidResultSkipResult](rapidata/api_client/docs/IRapidResultSkipResult.md)
 - [IRapidResultTranscriptionResult](rapidata/api_client/docs/IRapidResultTranscriptionResult.md)
 - [IRefereeConfig](rapidata/api_client/docs/IRefereeConfig.md)
 - [IRefereeConfigNaiveRefereeConfig](rapidata/api_client/docs/IRefereeConfigNaiveRefereeConfig.md)
 - [IRefereeConfigNeverEndingRefereeConfig](rapidata/api_client/docs/IRefereeConfigNeverEndingRefereeConfig.md)
 - [IRefereeConfigProbabilisticAttachCategoryRefereeConfig](rapidata/api_client/docs/IRefereeConfigProbabilisticAttachCategoryRefereeConfig.md)
 - [IRefereeInfo](rapidata/api_client/docs/IRefereeInfo.md)
 - [IRefereeInfoNaiveRefereeInfo](rapidata/api_client/docs/IRefereeInfoNaiveRefereeInfo.md)
 - [IRefereeInfoNeverEndingRefereeInfo](rapidata/api_client/docs/IRefereeInfoNeverEndingRefereeInfo.md)
 - [IRefereeInfoProbabilisticAttachCategoryRefereeInfo](rapidata/api_client/docs/IRefereeInfoProbabilisticAttachCategoryRefereeInfo.md)
 - [IRefereeModel](rapidata/api_client/docs/IRefereeModel.md)
 - [IRefereeModelEarlyStoppingRefereeModel](rapidata/api_client/docs/IRefereeModelEarlyStoppingRefereeModel.md)
 - [IRefereeModelNaiveRefereeModel](rapidata/api_client/docs/IRefereeModelNaiveRefereeModel.md)
 - [ISelection](rapidata/api_client/docs/ISelection.md)
 - [ISelectionAbTestSelection](rapidata/api_client/docs/ISelectionAbTestSelection.md)
 - [ISelectionCappedSelection](rapidata/api_client/docs/ISelectionCappedSelection.md)
 - [ISelectionConditionalValidationSelection](rapidata/api_client/docs/ISelectionConditionalValidationSelection.md)
 - [ISelectionDemographicSelection](rapidata/api_client/docs/ISelectionDemographicSelection.md)
 - [ISelectionEffortCappedSelection](rapidata/api_client/docs/ISelectionEffortCappedSelection.md)
 - [ISelectionLabelingSelection](rapidata/api_client/docs/ISelectionLabelingSelection.md)
 - [ISelectionShufflingSelection](rapidata/api_client/docs/ISelectionShufflingSelection.md)
 - [ISelectionStaticSelection](rapidata/api_client/docs/ISelectionStaticSelection.md)
 - [ISelectionValidationSelection](rapidata/api_client/docs/ISelectionValidationSelection.md)
 - [IUserFilterModel](rapidata/api_client/docs/IUserFilterModel.md)
 - [IUserFilterModelAgeUserFilterModel](rapidata/api_client/docs/IUserFilterModelAgeUserFilterModel.md)
 - [IUserFilterModelAndUserFilterModel](rapidata/api_client/docs/IUserFilterModelAndUserFilterModel.md)
 - [IUserFilterModelCampaignUserFilterModel](rapidata/api_client/docs/IUserFilterModelCampaignUserFilterModel.md)
 - [IUserFilterModelCountryUserFilterModel](rapidata/api_client/docs/IUserFilterModelCountryUserFilterModel.md)
 - [IUserFilterModelCustomUserFilterModel](rapidata/api_client/docs/IUserFilterModelCustomUserFilterModel.md)
 - [IUserFilterModelGenderUserFilterModel](rapidata/api_client/docs/IUserFilterModelGenderUserFilterModel.md)
 - [IUserFilterModelLanguageUserFilterModel](rapidata/api_client/docs/IUserFilterModelLanguageUserFilterModel.md)
 - [IUserFilterModelNewUserFilterModel](rapidata/api_client/docs/IUserFilterModelNewUserFilterModel.md)
 - [IUserFilterModelNotUserFilterModel](rapidata/api_client/docs/IUserFilterModelNotUserFilterModel.md)
 - [IUserFilterModelOrUserFilterModel](rapidata/api_client/docs/IUserFilterModelOrUserFilterModel.md)
 - [IUserFilterModelResponseCountUserFilterModel](rapidata/api_client/docs/IUserFilterModelResponseCountUserFilterModel.md)
 - [IUserFilterModelUserScoreUserFilterModel](rapidata/api_client/docs/IUserFilterModelUserScoreUserFilterModel.md)
 - [IValidationMetadataInput](rapidata/api_client/docs/IValidationMetadataInput.md)
 - [IValidationMetadataInputPromptAssetMetadataInput](rapidata/api_client/docs/IValidationMetadataInputPromptAssetMetadataInput.md)
 - [IValidationMetadataInputPromptMetadataInput](rapidata/api_client/docs/IValidationMetadataInputPromptMetadataInput.md)
 - [IValidationTruth](rapidata/api_client/docs/IValidationTruth.md)
 - [IValidationTruthAttachCategoryTruth](rapidata/api_client/docs/IValidationTruthAttachCategoryTruth.md)
 - [IValidationTruthBoundingBoxTruth](rapidata/api_client/docs/IValidationTruthBoundingBoxTruth.md)
 - [IValidationTruthCompareTruth](rapidata/api_client/docs/IValidationTruthCompareTruth.md)
 - [IValidationTruthEmptyValidationTruth](rapidata/api_client/docs/IValidationTruthEmptyValidationTruth.md)
 - [IValidationTruthLineTruth](rapidata/api_client/docs/IValidationTruthLineTruth.md)
 - [IValidationTruthLocateBoxTruth](rapidata/api_client/docs/IValidationTruthLocateBoxTruth.md)
 - [IValidationTruthMultiCompareTruth](rapidata/api_client/docs/IValidationTruthMultiCompareTruth.md)
 - [IValidationTruthNamedEntityTruth](rapidata/api_client/docs/IValidationTruthNamedEntityTruth.md)
 - [IValidationTruthPolygonTruth](rapidata/api_client/docs/IValidationTruthPolygonTruth.md)
 - [IValidationTruthScrubTruth](rapidata/api_client/docs/IValidationTruthScrubTruth.md)
 - [IValidationTruthSkipTruth](rapidata/api_client/docs/IValidationTruthSkipTruth.md)
 - [IValidationTruthTranscriptionTruth](rapidata/api_client/docs/IValidationTruthTranscriptionTruth.md)
 - [IWorkflowConfig](rapidata/api_client/docs/IWorkflowConfig.md)
 - [IWorkflowConfigCompareWorkflowConfig](rapidata/api_client/docs/IWorkflowConfigCompareWorkflowConfig.md)
 - [IWorkflowConfigEvaluationWorkflowConfig](rapidata/api_client/docs/IWorkflowConfigEvaluationWorkflowConfig.md)
 - [IWorkflowConfigGroupedRankingWorkflowConfig](rapidata/api_client/docs/IWorkflowConfigGroupedRankingWorkflowConfig.md)
 - [IWorkflowConfigSimpleWorkflowConfig](rapidata/api_client/docs/IWorkflowConfigSimpleWorkflowConfig.md)
 - [IWorkflowModel](rapidata/api_client/docs/IWorkflowModel.md)
 - [IWorkflowModelCompareWorkflowModel](rapidata/api_client/docs/IWorkflowModelCompareWorkflowModel.md)
 - [IWorkflowModelEvaluationWorkflowModel](rapidata/api_client/docs/IWorkflowModelEvaluationWorkflowModel.md)
 - [IWorkflowModelGroupedRankingWorkflowModel](rapidata/api_client/docs/IWorkflowModelGroupedRankingWorkflowModel.md)
 - [IWorkflowModelSimpleWorkflowModel](rapidata/api_client/docs/IWorkflowModelSimpleWorkflowModel.md)
 - [InspectReportResult](rapidata/api_client/docs/InspectReportResult.md)
 - [JsonWebKey](rapidata/api_client/docs/JsonWebKey.md)
 - [JsonWebKeySet](rapidata/api_client/docs/JsonWebKeySet.md)
 - [LeaderboardsQueryResult](rapidata/api_client/docs/LeaderboardsQueryResult.md)
 - [LineResultLine](rapidata/api_client/docs/LineResultLine.md)
 - [LineResultLinePoint](rapidata/api_client/docs/LineResultLinePoint.md)
 - [LocateCoordinate](rapidata/api_client/docs/LocateCoordinate.md)
 - [LogicOperator](rapidata/api_client/docs/LogicOperator.md)
 - [MetadataIOrderMetadataInput](rapidata/api_client/docs/MetadataIOrderMetadataInput.md)
 - [MetadataIOrderMetadataInputMetadataPromptAssetMetadataInput](rapidata/api_client/docs/MetadataIOrderMetadataInputMetadataPromptAssetMetadataInput.md)
 - [MetadataIOrderMetadataInputMetadataPromptMetadataInput](rapidata/api_client/docs/MetadataIOrderMetadataInputMetadataPromptMetadataInput.md)
 - [MetadataIOrderMetadataInputMetadataTranscriptionMetadataInput](rapidata/api_client/docs/MetadataIOrderMetadataInputMetadataTranscriptionMetadataInput.md)
 - [NamedClassification](rapidata/api_client/docs/NamedClassification.md)
 - [NewsletterModel](rapidata/api_client/docs/NewsletterModel.md)
 - [NotAvailableYetResult](rapidata/api_client/docs/NotAvailableYetResult.md)
 - [OrderModel](rapidata/api_client/docs/OrderModel.md)
 - [OrderState](rapidata/api_client/docs/OrderState.md)
 - [PageInfo](rapidata/api_client/docs/PageInfo.md)
 - [PagedResultOfAggregatedOrdersModel](rapidata/api_client/docs/PagedResultOfAggregatedOrdersModel.md)
 - [PagedResultOfBenchmarkQueryResult](rapidata/api_client/docs/PagedResultOfBenchmarkQueryResult.md)
 - [PagedResultOfCampaignQueryResult](rapidata/api_client/docs/PagedResultOfCampaignQueryResult.md)
 - [PagedResultOfClientsQueryResult](rapidata/api_client/docs/PagedResultOfClientsQueryResult.md)
 - [PagedResultOfGetCompareWorkflowResultsResult](rapidata/api_client/docs/PagedResultOfGetCompareWorkflowResultsResult.md)
 - [PagedResultOfGetGroupedRankingWorkflowResultsResult](rapidata/api_client/docs/PagedResultOfGetGroupedRankingWorkflowResultsResult.md)
 - [PagedResultOfGetValidationRapidsResult](rapidata/api_client/docs/PagedResultOfGetValidationRapidsResult.md)
 - [PagedResultOfGetWorkflowResultsResult](rapidata/api_client/docs/PagedResultOfGetWorkflowResultsResult.md)
 - [PagedResultOfIWorkflowModel](rapidata/api_client/docs/PagedResultOfIWorkflowModel.md)
 - [PagedResultOfLeaderboardsQueryResult](rapidata/api_client/docs/PagedResultOfLeaderboardsQueryResult.md)
 - [PagedResultOfOrderModel](rapidata/api_client/docs/PagedResultOfOrderModel.md)
 - [PagedResultOfParticipantByBenchmark](rapidata/api_client/docs/PagedResultOfParticipantByBenchmark.md)
 - [PagedResultOfPromptByBenchmarkResult](rapidata/api_client/docs/PagedResultOfPromptByBenchmarkResult.md)
 - [PagedResultOfQueryAudiencesResult](rapidata/api_client/docs/PagedResultOfQueryAudiencesResult.md)
 - [PagedResultOfQueryDatapointsByDatasetIdResult](rapidata/api_client/docs/PagedResultOfQueryDatapointsByDatasetIdResult.md)
 - [PagedResultOfQueryValidationRapidEligibilityResult](rapidata/api_client/docs/PagedResultOfQueryValidationRapidEligibilityResult.md)
 - [PagedResultOfRapidModel](rapidata/api_client/docs/PagedResultOfRapidModel.md)
 - [PagedResultOfRunsByLeaderboardResult](rapidata/api_client/docs/PagedResultOfRunsByLeaderboardResult.md)
 - [PagedResultOfSampleByIdentifier](rapidata/api_client/docs/PagedResultOfSampleByIdentifier.md)
 - [PagedResultOfSampleByParticipant](rapidata/api_client/docs/PagedResultOfSampleByParticipant.md)
 - [PagedResultOfStandingByLeaderboard](rapidata/api_client/docs/PagedResultOfStandingByLeaderboard.md)
 - [PagedResultOfValidationSetModel](rapidata/api_client/docs/PagedResultOfValidationSetModel.md)
 - [ParticipantByBenchmark](rapidata/api_client/docs/ParticipantByBenchmark.md)
 - [ParticipantStatus](rapidata/api_client/docs/ParticipantStatus.md)
 - [PolygonResultCoordinate](rapidata/api_client/docs/PolygonResultCoordinate.md)
 - [PolygonResultShape](rapidata/api_client/docs/PolygonResultShape.md)
 - [PreliminaryDownloadModel](rapidata/api_client/docs/PreliminaryDownloadModel.md)
 - [PreviewOrderModel](rapidata/api_client/docs/PreviewOrderModel.md)
 - [ProblemDetails](rapidata/api_client/docs/ProblemDetails.md)
 - [PromptByBenchmarkResult](rapidata/api_client/docs/PromptByBenchmarkResult.md)
 - [PublicOrderModel](rapidata/api_client/docs/PublicOrderModel.md)
 - [QueryAudiencesResult](rapidata/api_client/docs/QueryAudiencesResult.md)
 - [QueryDatapointsByDatasetIdResult](rapidata/api_client/docs/QueryDatapointsByDatasetIdResult.md)
 - [QueryModel](rapidata/api_client/docs/QueryModel.md)
 - [QueryValidationRapidEligibilityModelQueryValidationModel](rapidata/api_client/docs/QueryValidationRapidEligibilityModelQueryValidationModel.md)
 - [QueryValidationRapidEligibilityResult](rapidata/api_client/docs/QueryValidationRapidEligibilityResult.md)
 - [RapidIssue](rapidata/api_client/docs/RapidIssue.md)
 - [RapidModel](rapidata/api_client/docs/RapidModel.md)
 - [RapidResultModel](rapidata/api_client/docs/RapidResultModel.md)
 - [RapidSkippedModel](rapidata/api_client/docs/RapidSkippedModel.md)
 - [RapidState](rapidata/api_client/docs/RapidState.md)
 - [ReadBridgeTokenKeysResult](rapidata/api_client/docs/ReadBridgeTokenKeysResult.md)
 - [ReportModel](rapidata/api_client/docs/ReportModel.md)
 - [RetrievalMode](rapidata/api_client/docs/RetrievalMode.md)
 - [RootFilter](rapidata/api_client/docs/RootFilter.md)
 - [RunStatus](rapidata/api_client/docs/RunStatus.md)
 - [RunsByLeaderboardResult](rapidata/api_client/docs/RunsByLeaderboardResult.md)
 - [SampleByIdentifier](rapidata/api_client/docs/SampleByIdentifier.md)
 - [SampleByParticipant](rapidata/api_client/docs/SampleByParticipant.md)
 - [ScrubRange](rapidata/api_client/docs/ScrubRange.md)
 - [SendSurveyModel](rapidata/api_client/docs/SendSurveyModel.md)
 - [SortCriterion](rapidata/api_client/docs/SortCriterion.md)
 - [SortDirection](rapidata/api_client/docs/SortDirection.md)
 - [StandingByBenchmark](rapidata/api_client/docs/StandingByBenchmark.md)
 - [StandingByLeaderboard](rapidata/api_client/docs/StandingByLeaderboard.md)
 - [StandingStatus](rapidata/api_client/docs/StandingStatus.md)
 - [StandingsByBenchmarkResult](rapidata/api_client/docs/StandingsByBenchmarkResult.md)
 - [StandingsByLeaderboardResult](rapidata/api_client/docs/StandingsByLeaderboardResult.md)
 - [StartPreliminaryDownloadResult](rapidata/api_client/docs/StartPreliminaryDownloadResult.md)
 - [StickyState](rapidata/api_client/docs/StickyState.md)
 - [SubmitOrderModel](rapidata/api_client/docs/SubmitOrderModel.md)
 - [SubmitParticipantResult](rapidata/api_client/docs/SubmitParticipantResult.md)
 - [SubmitPromptModel](rapidata/api_client/docs/SubmitPromptModel.md)
 - [TagsByBenchmarkResult](rapidata/api_client/docs/TagsByBenchmarkResult.md)
 - [TranscriptionWord](rapidata/api_client/docs/TranscriptionWord.md)
 - [TranslatedString](rapidata/api_client/docs/TranslatedString.md)
 - [UnlockOrderResult](rapidata/api_client/docs/UnlockOrderResult.md)
 - [UpdateAudienceRequest](rapidata/api_client/docs/UpdateAudienceRequest.md)
 - [UpdateBenchmarkModel](rapidata/api_client/docs/UpdateBenchmarkModel.md)
 - [UpdateBenchmarkNameModel](rapidata/api_client/docs/UpdateBenchmarkNameModel.md)
 - [UpdateCampaignModel](rapidata/api_client/docs/UpdateCampaignModel.md)
 - [UpdateDatasetNameModel](rapidata/api_client/docs/UpdateDatasetNameModel.md)
 - [UpdateDimensionsModel](rapidata/api_client/docs/UpdateDimensionsModel.md)
 - [UpdateLeaderboardModel](rapidata/api_client/docs/UpdateLeaderboardModel.md)
 - [UpdateLeaderboardNameModel](rapidata/api_client/docs/UpdateLeaderboardNameModel.md)
 - [UpdateLeaderboardResponseConfigModel](rapidata/api_client/docs/UpdateLeaderboardResponseConfigModel.md)
 - [UpdateOrderNameModel](rapidata/api_client/docs/UpdateOrderNameModel.md)
 - [UpdateParticipantModel](rapidata/api_client/docs/UpdateParticipantModel.md)
 - [UpdateParticipantNameModel](rapidata/api_client/docs/UpdateParticipantNameModel.md)
 - [UpdatePriorityModel](rapidata/api_client/docs/UpdatePriorityModel.md)
 - [UpdatePromptTagsModel](rapidata/api_client/docs/UpdatePromptTagsModel.md)
 - [UpdateShouldAlertModel](rapidata/api_client/docs/UpdateShouldAlertModel.md)
 - [UpdateValidationRapidModel](rapidata/api_client/docs/UpdateValidationRapidModel.md)
 - [UpdateValidationSetModel](rapidata/api_client/docs/UpdateValidationSetModel.md)
 - [UploadFileResult](rapidata/api_client/docs/UploadFileResult.md)
 - [ValidationSetModel](rapidata/api_client/docs/ValidationSetModel.md)
 - [ValidationSetOverviewModel](rapidata/api_client/docs/ValidationSetOverviewModel.md)
 - [WorkflowState](rapidata/api_client/docs/WorkflowState.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="Bearer"></a>
### Bearer

- **Type**: Bearer authentication (Json Web Token)

<a id="OpenIdConnect"></a>
### OpenIdConnect


<a id="OAuth2"></a>
### OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://auth.rabbitdata.ch/connect/authorize
- **Scopes**: 
 - **openid**: OpenID
 - **profile**: Profile
 - **email**: Email


## Author




